==> cdk-amazon-chime-resources-0.0.7.tar.gz: package/lib/voiceConnector.d.ts <==
import { Construct } from 'constructs';
/**
 * @stability stable
 */
export declare enum NotificationTargetType {
    /**
     * @stability stable
     */
    EVENTBRIDGE = "EventBridge",
    /**
     * @stability stable
     */
    SNS = "SNS",
    /**
     * @stability stable
     */
    SQS = "SQS"
}
/**
 * @stability stable
 */
export declare enum Protocol {
    /**
     * @stability stable
     */
    TCP = "TCP",
    /**
     * @stability stable
     */
    UDP = "UDP"
}
/**
 * @stability stable
 */
export interface Termination {
    /**
     * Calling Regions for VoiceConnector (optional).
     *
     * @default - ['US']
     * @stability stable
     */
    readonly callingRegions: Array<string>;
    /**
     * termination IP for VoiceConnector (optional).
     *
     * @default - none
     * @stability stable
     */
    readonly terminationCidrs: Array<string>;
}
/**
 * @stability stable
 */
export interface Routes {
    /**
     * @stability stable
     */
    readonly host: string;
    /**
     * @stability stable
     */
    readonly port: number;
    /**
     * @stability stable
     */
    readonly protocol: Protocol;
    /**
     * @stability stable
     */
    readonly priority: number;
    /**
     * @stability stable
     */
    readonly weight: number;
}
/**
 * @stability stable
 */
export interface Streaming {
    /**
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * Streaming data retention for VoiceConnector.
     *
     * @default - 0
     * @stability stable
     */
    readonly dataRetention: number;
    /**
     * Streaming data retention for VoiceConnector.
     *
     * @default - 0
     * @stability stable
     */
    readonly notificationTargets: Array<NotificationTargetType>;
}
/**
 * Props for `SipMediaApplication`.
 *
 * @stability stable
 */
export interface VoiceConnectorProps {
    /**
     * region for SipMediaApplication(required) - Must us-east-1 or us-west-2 and in the same region as the SipMediaApplication Lambda handler.
     *
     * @default - same region as stack deployment
     * @stability stable
     */
    readonly region?: string;
    /**
     * name for VoiceConnector.
     *
     * @default - unique ID for resource
     * @stability stable
     */
    readonly name?: string;
    /**
     * Encryption boolean for VoiceConnector.
     *
     * @default - False
     * @stability stable
     */
    readonly encryption?: boolean;
    /**
     * @stability stable
     */
    readonly termination?: Termination;
    /**
     * @stability stable
     */
    readonly origination?: Array<Routes>;
    /**
     * @stability stable
     */
    readonly streaming?: Streaming;
}
/**
 * @stability stable
 */
export declare class ChimeVoiceConnector extends Construct {
    /**
     * @stability stable
     */
    readonly voiceConnectorId: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: VoiceConnectorProps);
}

==> cdk-amazon-chime-resources-0.0.66.tar.gz: package/lib/voiceConnector.d.ts <==
import { Construct } from 'constructs';
export declare enum NotificationTargetType {
    EVENTBRIDGE = "EventBridge",
    SNS = "SNS",
    SQS = "SQS"
}
export declare enum Protocol {
    TCP = "TCP",
    UDP = "UDP"
}
export interface Termination {
    /**
     * Calling Regions for VoiceConnector (optional)
     *
     * @default - ['US']
     */
    readonly callingRegions: Array<string>;
    /**
     * termination IP for VoiceConnector (optional)
     *
     * @default - none
     */
    readonly terminationCidrs: Array<string>;
}
export interface Routes {
    readonly host: string;
    readonly port: number;
    readonly protocol: Protocol;
    readonly priority: number;
    readonly weight: number;
}
export interface Streaming {
    readonly enabled: boolean;
    /**
     * Streaming data retention for VoiceConnector
     *
     * @default - 0
     */
    readonly dataRetention: number;
    /**
     * Streaming data retention for VoiceConnector
     *
     * @default - 0
     */
    readonly notificationTargets: Array<NotificationTargetType>;
}
/**
 * Props for `SipMediaApplication`.
 */
export interface VoiceConnectorProps {
    /**
     * region for SipMediaApplication(required) - Must us-east-1 or us-west-2 and in the same region as the SipMediaApplication Lambda handler
     *
     * @default - same region as stack deployment
     */
    readonly region?: string;
    /**
     * name for VoiceConnector
     *
     * @default - unique ID for resource
     */
    readonly name?: string;
    /**
     * Encryption boolean for VoiceConnector
     *
     * @default - False
     */
    readonly encryption?: boolean;
    readonly termination?: Termination;
    readonly origination?: Array<Routes>;
    readonly streaming?: Streaming;
}
export declare class ChimeVoiceConnector extends Construct {
    readonly voiceConnectorId: string;
    constructor(scope: Construct, id: string, props: VoiceConnectorProps);
}
